# gerarPalavra

**gerarPalavra** .

## Dependências
**Python 3.6** ou posterior




## Começando o uso
Você vai precisar instalar o pacote **gerarPalavra**, para isso basta executar:
```
pip install gerarPalavra
```

## Função

* `gerarLetra()` - Gera uma palavra dissilaba
* `guardar(palavra)` - Armazena a palavra em um arquivo .txt
